# Harbor App

Companion app for Harbor.

## Recommended IDE Setup

- [VS Code](https://code.visualstudio.com/) + [Tauri](https://marketplace.visualstudio.com/items?itemName=tauri-apps.tauri-vscode) + [rust-analyzer](https://marketplace.visualstudio.com/items?itemName=rust-lang.rust-analyzer)

## Development

```bash
# Change to the app directory
cd ./app

# Install dependencies
bun install

# Run the app in development mode
bun tauri dev
```